@@ -1,6 +1,7 @@
-use crate::point::Vec2DDrawing;
+use crate::point::Vec2DWorld;
 use crate::color::Color;
 use crate::shape::path::PathCommand;
+use crate::geom::Angle;
 
 /// The draw command as returned by the shape: adds the color
 #[derive(Debug, PartialEq, Clone)]
@@ -10,14 +11,19 @@ pub enum DrawCommand {
         commands: Vec<PathCommand>,
         thickness: f64,
     },
+
     Circle {
-        center: Vec2DDrawing,
+        center: Vec2DWorld,
         radius: f64,
         color: Color,
         thickness: f64,
     },
+
     Ellipse {
-        bbox: [Vec2DDrawing; 2],
+        center: Vec2DWorld,
+        semimajor: f64,
+        semiminor: f64,
+        angle: Angle,
         thickness: f64,
         color: Color,
     },
